from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ImageRGBA(_message.Message):
    __slots__ = ("timestamp", "width", "height", "pixels")
    class Pixel(_message.Message):
        __slots__ = ("red", "green", "blue", "alpha")
        RED_FIELD_NUMBER: _ClassVar[int]
        GREEN_FIELD_NUMBER: _ClassVar[int]
        BLUE_FIELD_NUMBER: _ClassVar[int]
        ALPHA_FIELD_NUMBER: _ClassVar[int]
        red: int
        green: int
        blue: int
        alpha: int
        def __init__(self, red: _Optional[int] = ..., green: _Optional[int] = ..., blue: _Optional[int] = ..., alpha: _Optional[int] = ...) -> None: ...
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PIXELS_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    width: int
    height: int
    pixels: _containers.RepeatedCompositeFieldContainer[ImageRGBA.Pixel]
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., width: _Optional[int] = ..., height: _Optional[int] = ..., pixels: _Optional[_Iterable[_Union[ImageRGBA.Pixel, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/tensor/matrix_44.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&make87_messages/tensor/matrix_44.proto\x12\x17make87_messages.tensors\x1a\x1fgoogle/protobuf/timestamp.proto\"\x89\x02\n\x08Matrix44\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03m00\x18\x02 \x01(\x02\x12\x0b\n\x03m01\x18\x03 \x01(\x02\x12\x0b\n\x03m02\x18\x04 \x01(\x02\x12\x0b\n\x03m03\x18\x05 \x01(\x02\x12\x0b\n\x03m10\x18\x06 \x01(\x02\x12\x0b\n\x03m11\x18\x07 \x01(\x02\x12\x0b\n\x03m12\x18\x08 \x01(\x02\x12\x0b\n\x03m13\x18\t \x01(\x02\x12\x0b\n\x03m20\x18\n \x01(\x02\x12\x0b\n\x03m21\x18\x0b \x01(\x02\x12\x0b\n\x03m22\x18\x0c \x01(\x02\x12\x0b\n\x03m23\x18\r \x01(\x02\x12\x0b\n\x03m30\x18\x0e \x01(\x02\x12\x0b\n\x03m31\x18\x0f \x01(\x02\x12\x0b\n\x03m32\x18\x10 \x01(\x02\x12\x0b\n\x03m33\x18\x11 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.tensor.matrix_44_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MATRIX44']._serialized_start=101
  _globals['_MATRIX44']._serialized_end=366
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/geometry/box/boxes_2d.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.geometry.box import box_2d_pb2 as make87__messages_dot_geometry_dot_box_dot_box__2d__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+make87_messages/geometry/box/boxes_2d.proto\x12\x1cmake87_messages.geometry.box\x1a)make87_messages/geometry/box/box_2d.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"l\n\x07\x42oxes2D\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x05\x62oxes\x18\x02 \x03(\x0b\x32#.make87_messages.geometry.box.Box2D\"\x82\x01\n\x12\x42oxes2DAxisAligned\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x05\x62oxes\x18\x02 \x03(\x0b\x32..make87_messages.geometry.box.Box2DAxisAlignedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.geometry.box.boxes_2d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BOXES2D']._serialized_start=153
  _globals['_BOXES2D']._serialized_end=261
  _globals['_BOXES2DAXISALIGNED']._serialized_start=264
  _globals['_BOXES2DAXISALIGNED']._serialized_end=394
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/image/uncompressed/image_gray.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3make87_messages/image/uncompressed/image_gray.proto\x12#make87_messages.images.uncompressed\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbb\x01\n\tImageGray\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\x12\x44\n\x06pixels\x18\x04 \x03(\x0b\x32\x34.make87_messages.images.uncompressed.ImageGray.Pixel\x1a\x1a\n\x05Pixel\x12\x11\n\tintensity\x18\x01 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.image.uncompressed.image_gray_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_IMAGEGRAY']._serialized_start=126
  _globals['_IMAGEGRAY']._serialized_end=313
  _globals['_IMAGEGRAY_PIXEL']._serialized_start=287
  _globals['_IMAGEGRAY_PIXEL']._serialized_end=313
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ImageRGB(_message.Message):
    __slots__ = ("timestamp", "data", "width", "height")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    data: bytes
    width: int
    height: int
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., data: _Optional[bytes] = ..., width: _Optional[int] = ..., height: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/spatial/pose/pose_3d.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from make87_messages.spatial.rotation import quaternion_pb2 as make87__messages_dot_spatial_dot_rotation_dot_quaternion__pb2
from make87_messages.spatial.translation import translation_3d_pb2 as make87__messages_dot_spatial_dot_translation_dot_translation__3d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*make87_messages/spatial/pose/pose_3d.proto\x12\x1cmake87_messages.spatial.pose\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31make87_messages/spatial/rotation/quaternion.proto\x1a\x38make87_messages/spatial/translation/translation_3d.proto\"\xc0\x01\n\x06Pose3D\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x0btranslation\x18\x02 \x01(\x0b\x32\x32.make87_messages.spatial.translation.Translation3D\x12>\n\x08rotation\x18\x03 \x01(\x0b\x32,.make87_messages.spatial.rotation.Quaternionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.spatial.pose.pose_3d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_POSE3D']._serialized_start=219
  _globals['_POSE3D']._serialized_end=411
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Matrix44(_message.Message):
    __slots__ = ("timestamp", "m00", "m01", "m02", "m03", "m10", "m11", "m12", "m13", "m20", "m21", "m22", "m23", "m30", "m31", "m32", "m33")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    M00_FIELD_NUMBER: _ClassVar[int]
    M01_FIELD_NUMBER: _ClassVar[int]
    M02_FIELD_NUMBER: _ClassVar[int]
    M03_FIELD_NUMBER: _ClassVar[int]
    M10_FIELD_NUMBER: _ClassVar[int]
    M11_FIELD_NUMBER: _ClassVar[int]
    M12_FIELD_NUMBER: _ClassVar[int]
    M13_FIELD_NUMBER: _ClassVar[int]
    M20_FIELD_NUMBER: _ClassVar[int]
    M21_FIELD_NUMBER: _ClassVar[int]
    M22_FIELD_NUMBER: _ClassVar[int]
    M23_FIELD_NUMBER: _ClassVar[int]
    M30_FIELD_NUMBER: _ClassVar[int]
    M31_FIELD_NUMBER: _ClassVar[int]
    M32_FIELD_NUMBER: _ClassVar[int]
    M33_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    m00: float
    m01: float
    m02: float
    m03: float
    m10: float
    m11: float
    m12: float
    m13: float
    m20: float
    m21: float
    m22: float
    m23: float
    m30: float
    m31: float
    m32: float
    m33: float
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., m00: _Optional[float] = ..., m01: _Optional[float] = ..., m02: _Optional[float] = ..., m03: _Optional[float] = ..., m10: _Optional[float] = ..., m11: _Optional[float] = ..., m12: _Optional[float] = ..., m13: _Optional[float] = ..., m20: _Optional[float] = ..., m21: _Optional[float] = ..., m22: _Optional[float] = ..., m23: _Optional[float] = ..., m30: _Optional[float] = ..., m31: _Optional[float] = ..., m32: _Optional[float] = ..., m33: _Optional[float] = ...) -> None: ...
